If you would like to contribute to the development of OpenStack,
you must follow the steps documented at:

   http://docs.openstack.org/developer/horizon/contributing.html

   or https://wiki.openstack.org/wiki/How_To_Contribute#If_you.27re_a_developer

Once those steps have been completed, changes to OpenStack
should be submitted for review via the Gerrit tool, following
the workflow documented at:

   https://wiki.openstack.org/GerritWorkflow

Pull requests submitted through GitHub will be ignored.

Bugs should be filed on Launchpad, not GitHub:

   https://bugs.launchpad.net/horizon
